@@ -1,8 +1,10 @@
-"""Parsing functions for Binvox files.
+"""
+Parsing functions for Binvox files.
 
 https://www.patrickmin.com/binvox/binvox.html
 
-Exporting meshes as binvox files requires binvox CL tool to be on your path.
+Exporting meshes as binvox files requires the
+`binvox` executable to be in your path.
 """
 import os
 import subprocess
@@ -14,7 +16,7 @@ from distutils.spawn import find_executable
 from .. import util
 from ..base import Trimesh
 
-# find the executable
+# find the executable for binvox in PATH
 binvox_encoder = find_executable('binvox')
 
 Binvox = collections.namedtuple(
@@ -150,7 +152,7 @@ def binvox_bytes(rle_data, shape, translate=(0, 0, 0), scale=1):
             "rle_data.dtype must be np.uint8, got %s" % rle_data.dtype)
 
     header = binvox_header(shape, translate, scale).encode()
-    return header + rle_data.tostring()
+    return header + rle_data.tobytes()
 
 
 def voxel_from_binvox(
@@ -345,28 +347,27 @@ class Binvoxer(object):
     )
 
     def __init__(
-        self,
-        dimension=32,
-        file_type='binvox',
-        z_buffer_carving=True,
-        z_buffer_voting=True,
-        dilated_carving=False,
-        exact=False,
-        bounding_box=None,
-        remove_internal=False,
-        center=False,
-        rotate_x=0,
-        rotate_z=0,
-        wireframe=False,
-        fit=False,
-        block_id=None,
-        use_material_block_id=False,
-        use_offscreen_pbuffer=True,
-        downsample_factor=None,
-        downsample_threshold=None,
-        verbose=False,
-        binvox_path=binvox_encoder,
-    ):
+            self,
+            dimension=32,
+            file_type='binvox',
+            z_buffer_carving=True,
+            z_buffer_voting=True,
+            dilated_carving=False,
+            exact=False,
+            bounding_box=None,
+            remove_internal=False,
+            center=False,
+            rotate_x=0,
+            rotate_z=0,
+            wireframe=False,
+            fit=False,
+            block_id=None,
+            use_material_block_id=False,
+            use_offscreen_pbuffer=True,
+            downsample_factor=None,
+            downsample_threshold=None,
+            verbose=False,
+            binvox_path=None):
         """
         Configure the voxelizer.
 
@@ -409,15 +410,22 @@ class Binvoxer(object):
             errors occur, try slightly adjusting dimensions.
         downsample_threshold: when downsampling, destination voxel is on if
             more than this number of voxels are on.
-        verbose: if False, silences stdout/stderr from subprocess call.
-        binvox_path: path to binvox executable. The default looks for an
-            executable called `binvox` on your `PATH`.
+        verbose : bool
+          If False, silences stdout/stderr from subprocess call.
+        binvox_path : str
+          Path to binvox executable. The default looks for an
+          executable called `binvox` on your `PATH`.
         """
-        if binvox_encoder is None:
-            raise IOError(
-                'No `binvox_path` provided, and no binvox executable found '
-                'on PATH. \nPlease go to https://www.patrickmin.com/binvox/ and '
-                'download the appropriate version.')
+        if binvox_path is None:
+            encoder = binvox_encoder
+        else:
+            encoder = binvox_path
+
+        if encoder is None:
+            raise IOError(' '.join([
+                'No `binvox_path` provided and no binvox executable found',
+                'on PATH, please go to https://www.patrickmin.com/binvox/ and',
+                'download the appropriate version.']))
 
         if dimension > 1024 and not exact:
             raise ValueError(
@@ -426,7 +434,7 @@ class Binvoxer(object):
             raise ValueError(
                 'file_type %s not in set of supported output types %s' %
                 (file_type, str(Binvoxer.SUPPORTED_OUTPUT_TYPES)))
-        args = [binvox_path, '-d', str(dimension), '-t', file_type]
+        args = [encoder, '-d', str(dimension), '-t', file_type]
         if exact:
             args.append('-e')
         if z_buffer_carving:
@@ -438,8 +446,7 @@ class Binvoxer(object):
             args.append('-v')
         else:
             raise ValueError(
-                'At least one of `z_buffer_carving` or `z_buffer_voting` must '
-                'be True')
+                'One of `z_buffer_carving` or `z_buffer_voting` must be True')
         if dilated_carving:
             args.append('-dc')
 
@@ -515,9 +522,7 @@ class Binvoxer(object):
                 (ext, str(Binvoxer.SUPPORTED_INPUT_TYPES)))
         out_path = '%s.%s' % (head, self._file_type)
         if os.path.isfile(out_path) and not overwrite:
-            raise IOError(
-                'Attempted to voxelize object a %s, but there is already a '
-                'file at output path %s' % (path, out_path))
+            raise IOError('Attempted to voxelize object at existing path')
         self._args[-1] = path
 
         # generalizes to python2 and python3
